(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{27:function(e,t,a){e.exports=a.p+"static/media/ico_recording.bc7d967a.svg"},28:function(e,t,a){e.exports=a(39)},39:function(e,t,a){"use strict";a.r(t);var n=a(6),r=a.n(n),c=a(24),o=a.n(c),s=a(0),i=a(1),l=a(11),d=a(2),u=a(3),p=a(22),m=a(41),b=a(42),g=(a(35),a(27)),f=a.n(g),h=a(21),v=function(e){Object(d.a)(a,e);var t=Object(u.a)(a);function a(){var e;Object(i.a)(this,a);for(var n=arguments.length,c=new Array(n),o=0;o<n;o++)c[o]=arguments[o];return(e=t.call.apply(t,[this].concat(c))).state={state:"Record",currentRecording:null},e.render=function(){var t=e.setState.bind(Object(l.a)(e)),a="Stop recording"===e.state.state,n=e.props.disabled;return r.a.createElement("div",null,r.a.createElement("h1",null,"Record Audio"),r.a.createElement(m.a,{src:f.a}),a&&r.a.createElement("span",{className:"mx-3"},"Recording..."),r.a.createElement(h.b,{canvasWidth:"0",canvasHeight:"0",foregroundColor:"#451285",state:a?h.a.START:h.a.STOP,onStop:function(e){var a=new FileReader;a.onloadend=function(){var e=a.result;p.a.setComponentValue({b64:e.substring(e.indexOf(";base64,")+";base64,".length),mime_type:e.substring(e.indexOf("data:")+"data:".length,e.indexOf(";base64,"))}),t({currentRecording:e,state:"Record another sound"})},a.readAsDataURL(e.blob)}}),r.a.createElement(b.a,{variant:"danger",className:"btn-inputs mx-2",disabled:n,onClick:function(){return t({state:a?"Stopping...":"Stop recording"})}},e.state.state))},e}return Object(s.a)(a)}(p.b),O=Object(p.c)(v);o.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(O,null)),document.getElementById("root"))}},[[28,1,2]]]);
//# sourceMappingURL=main.ddccec24.chunk.js.map