.upload-container{display:flex;width:100%;position:relative;grid-gap:40px;gap:40px}.upload-container aside img{max-width:160px;height:auto;text-align:c}.upload-box,.upload-container h2{text-align:center}.upload-box{width:120px;height:120px;padding:50px;display:flex;align-items:center;justify-content:center;flex-flow:column nowrap;font-size:20px;color:#555;border:5px dashed #c3c3c3;border-radius:12px;background-color:#fff}.gallary{width:500px;height:500px;overflow:scroll}.area__icon{font-size:64px;margin-top:20px}body{font-family:sans-serif}.overflow{overflow:scroll;height:300px}.img-container{text-align:center}
/*# sourceMappingURL=main.ffd9ca53.chunk.css.map */