(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{14:function(e,t,n){e.exports=n(21)},21:function(e,t,n){"use strict";n.r(t);var o=n(5),c=n.n(o),r=n(12),a=n.n(r),s=n(0),l=n(1),u=n(2),i=n(3),p=n(10),m=function(e){Object(u.a)(n,e);var t=Object(i.a)(n);function n(){var e;Object(l.a)(this,n);for(var o=arguments.length,r=new Array(o),a=0;a<o;a++)r[a]=arguments[a];return(e=t.call.apply(t,[this].concat(r))).state={numClicks:0,isFocused:!1},e.render=function(){var t=e.props.args.name,n=e.props.theme,o={};if(n){var r="1px solid ".concat(e.state.isFocused?n.primaryColor:"gray");o.border=r,o.outline=r}return c.a.createElement("span",null,"Hello, ",t,"! \xa0",c.a.createElement("button",{style:o,onClick:e.onClicked,disabled:e.props.disabled,onFocus:e._onFocus,onBlur:e._onBlur},"Click Me!"))},e.onClicked=function(){e.setState((function(e){return{numClicks:e.numClicks+1}}),(function(){return p.a.setComponentValue(e.state.numClicks)}))},e._onFocus=function(){e.setState({isFocused:!0})},e._onBlur=function(){e.setState({isFocused:!1})},e}return Object(s.a)(n)}(p.b),d=Object(p.c)(m);a.a.render(c.a.createElement(c.a.StrictMode,null,c.a.createElement(d,null)),document.getElementById("root"))}},[[14,1,2]]]);
//# sourceMappingURL=main.ab27507e.chunk.js.map