self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "0197dd0549420728d65efaf1e7fe27a1",
    "url": "./index.html"
  },
  {
    "revision": "d5e495eaa60596712181",
    "url": "./static/css/2.a7708dfc.chunk.css"
  },
  {
    "revision": "d5e495eaa60596712181",
    "url": "./static/js/2.a24c58de.chunk.js"
  },
  {
    "revision": "3dc2da520b7611f998bec3f8b32ee24e",
    "url": "./static/js/2.a24c58de.chunk.js.LICENSE.txt"
  },
  {
    "revision": "f5ce2621a008dbc84779",
    "url": "./static/js/main.30a77405.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);